/*------------- Telecommunications & Signal Processing Lab -------------
                           McGill University

Routine:
  int AOdecDevOpt (struct AD_DevOpt *DevOpt)

Purpose:
  Decode audio device output options

Description:
  This routine decodes an option for the audio device.  The routine AOinitOpt
  must be called first to initialize the option arguments.  If this routine
  fails to find an input audio file option, the argument pointer is reset to
  allow another routine to try to decode the option.

PARAMETERS:
  <-  int AOdecDevOpt
         -1 - End of arguments/options
          0 - Option not found
        >=1 - Option code
  <-> struct AD_DevOpt *DevOpt
      Audio device options

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.4 $  $Date: 1999/06/14 16:06:23 $

----------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADdecDevOpt.c 1.4 1999/06/14 AFsp-v4r3 $";

#include <libtsp.h>
#include <libtsp/AFpar.h>
#include <AO.h>
#include <AD.h>

#define ROUTINE		"ADdecDevOpt"
#define PGM		((UTgetProg ())[0] == '\0' ? ROUTINE : UTgetProg ())
#define ERRSTOP(text,par)	UThalt ("%s: %s: \"%s\"", PGM, text, par)
#define NELEM(array)	((sizeof array) / (sizeof array[0]))

#define RET_ERROR	-2
#define RET_END		-1

static const char *OTDevOpt[] = {
  "-V#", "--v*olume=",
  "-b#", "--b*alance=",
  "-p#", "--po*rts=",
  "-s#", "--s*rate=",
  "-m", "--mute",
  "-u", "--unmute",
  "**",
  NULL
};

static const char *SdefTab[] = { "def*ault", NULL };


int
ADdecDevOpt (struct AD_DevOpt *DevOpt)

{
  const char *OptArg;
  int n, Sindex;
  struct AO_CmdArg *Carg;

  Carg = AOArgs ();

  if (Carg->EndOptions)
    return 0;

  /* Decode output file options */
  Sindex = Carg->Index;
  n = UTgetOption (&Carg->Index, Carg->Argc, Carg->Argv, OTDevOpt, &OptArg);

  switch (n) {
  case RET_END:
    break;
  case RET_ERROR:
    UThalt ("%s: %s", PGM, ADM_BadOption);
    break;
  case 1:
  case 2:
    /* Output volume */
    if (STdec1float (OptArg, &DevOpt->Vol) ||
	DevOpt->Vol < 0.0 || DevOpt->Vol > 100.0)
      ERRSTOP (ADM_BadVol, OptArg);
    break;
  case 3:
  case 4:
    /* Stereo balance */
    if (STdec1float (OptArg, &DevOpt->Balance) ||
	DevOpt->Balance < 0.0 || DevOpt->Balance > 100.0)
      ERRSTOP (ADM_BadBal, OptArg);
    break;
  case 5:
  case 6:
    /* Output port specification */
    ADdecOPort (OptArg, DevOpt->Ports);
    break;
  case 7:
  case 8:
    /* Sampling frequency */
    if (STkeyMatch (OptArg, SdefTab) == 0)
      DevOpt->Sfreq = SFREQ_DEFAULT;
    else if (STdec1float (OptArg, &DevOpt->Sfreq) || DevOpt->Sfreq < 0.0)
      ERRSTOP (ADM_BadSFreq, OptArg);
    break;
  case 9:
  case 10:
    /* Mute */
    DevOpt->Mute = MUTE_ON;
    break;
  case 11:
  case 12:
    /* Unmute */
    DevOpt->Mute = MUTE_OFF;
    break;
  default:
    Carg->Index = Sindex;		/* Reset the index */
    n = 0;
    break;
  }

  return n;
}
