/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  void ADgetOFormat (int audio_fd, float *Sfreq, int *Format, long int *Nchan)

Purpose:
  Get the output conversion parameters for the Sun audio device

Description:
  This routine gets the output conversion parameters for the Sun audio device.

Parameters:
   -> int audio_fd
      File descriptor for the audio device
  <-  float Sfreq
      Sampling frequency
  <-  int Format
      Data format, FD_MULAW8, FD_ALAW8, or FD_INT16
  <-  long int *Nchan
      Number of channels

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.9 $  $Date: 1999/06/14 16:13:02 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADgetOFormat.c 1.9 1999/06/14 AFsp-v4r3 $";

#include <stropts.h>		/* stream ioctl commands */
#include <unistd.h>		/* ioctl */

#include <libtsp.h>
#include <libtsp/AFpar.h>
#include <AD.h>

#define PGM		(UTgetProg ())


void
ADgetOFormat (int audio_fd, float *Sfreq, int *Format, long int *Nchan)

{
  int iost;
  audio_info_t aif;
  float sfreq;
  int format;
  long int nchan;

  iost = ioctl (audio_fd, AUDIO_GETINFO, &aif);
  if (iost == -1)
    UTerror ("%s: %s", PGM, ADM_GetErr);

/* Sample rate and number of channels */
  sfreq = aif.play.sample_rate;
  nchan = aif.play.channels;

/* Get up the data format */
  if (aif.play.encoding == AUDIO_ENCODING_LINEAR) {
    if (aif.play.precision == 16)
      format = FD_INT16;
    else if (aif.play.precision == 8)
      format = FD_INT8;
    else
      UThalt ("%s: %s: %ud", PGM, ADM_UnsIPrec, aif.play.precision);
  }
  else if (aif.play.encoding == AUDIO_ENCODING_ULAW) {
    if (aif.play.precision != 8)
      UThalt ("%s: %s: %ud", PGM, ADM_UnsMPrec, aif.play.precision);
    format = FD_MULAW8;
  }
  else if (aif.play.encoding == AUDIO_ENCODING_ALAW) {
    if (aif.play.precision != 8)
      UThalt ("%s: %s: %ud", PGM, ADM_UnsAPrec, aif.play.precision);
    format = FD_ALAW8;
  }
  else
    UThalt ("%s: %s: %ud", PGM, ADM_UnsData, aif.play.encoding);
  
/* Return the information */
  *Nchan = nchan;
  *Sfreq = sfreq;
  *Format = format;

  return;
}
